/*
 * Copyright (c) 2014, 2016-2017, The Linux Foundation. All rights reserved.
 * Permission to use, copy, modify, and/or distribute this software for
 * any purpose with or without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all copies.
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */



#include "sw.h"
#include "sw_ioctl.h"
#include "fal_trunk.h"
#include "fal_uk_if.h"


sw_error_t
fal_trunk_group_set(a_uint32_t dev_id, a_uint32_t trunk_id,
                    a_bool_t enable, fal_pbmp_t member)
{
    sw_error_t rv;

    rv = sw_uk_exec(SW_API_TRUNK_GROUP_SET, dev_id, trunk_id, enable,
                    (a_uint32_t) member);
    return rv;
}

sw_error_t
fal_trunk_group_get(a_uint32_t dev_id, a_uint32_t trunk_id,
                    a_bool_t * enable, fal_pbmp_t * member)
{
    sw_error_t rv;

    rv = sw_uk_exec(SW_API_TRUNK_GROUP_GET, dev_id, trunk_id, enable,
                    member);
    return rv;
}

sw_error_t
fal_trunk_hash_mode_set(a_uint32_t dev_id, a_uint32_t hash_mode)
{
    sw_error_t rv;

    rv = sw_uk_exec(SW_API_TRUNK_HASH_SET, dev_id, hash_mode);
    return rv;
}

sw_error_t
fal_trunk_hash_mode_get(a_uint32_t dev_id, a_uint32_t * hash_mode)
{
    sw_error_t rv;

    rv = sw_uk_exec(SW_API_TRUNK_HASH_GET, dev_id, hash_mode);
    return rv;
}

sw_error_t
fal_trunk_manipulate_sa_set(a_uint32_t dev_id, fal_mac_addr_t * addr)
{
    sw_error_t rv;

    rv = sw_uk_exec(SW_API_TRUNK_MAN_SA_SET, dev_id, addr);
    return rv;
}

sw_error_t
fal_trunk_manipulate_sa_get(a_uint32_t dev_id, fal_mac_addr_t * addr)
{
    sw_error_t rv;

    rv = sw_uk_exec(SW_API_TRUNK_MAN_SA_GET, dev_id, addr);
    return rv;
}

sw_error_t
fal_trunk_failover_enable(a_uint32_t dev_id, a_bool_t failover)

{
    sw_error_t rv;

    rv = sw_uk_exec(SW_API_TRUNK_FAILOVER_EN_SET, dev_id, failover);
    return rv;
}

sw_error_t
fal_trunk_failover_status_get(a_uint32_t dev_id, a_bool_t *failover)

{
    sw_error_t rv;

    rv = sw_uk_exec(SW_API_TRUNK_FAILOVER_EN_GET, dev_id, failover);
    return rv;
}


